summaryrefslogtreecommitdiff
path: root/src/mongo/db/matcher/extensions_callback_real.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/matcher/extensions_callback_real.h')
-rw-r--r--src/mongo/db/matcher/extensions_callback_real.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/mongo/db/matcher/extensions_callback_real.h b/src/mongo/db/matcher/extensions_callback_real.h
index 45b97e4b9c3..2cfbb043597 100644
--- a/src/mongo/db/matcher/extensions_callback_real.h
+++ b/src/mongo/db/matcher/extensions_callback_real.h
@@ -42,13 +42,14 @@ class OperationContext;
class ExtensionsCallbackReal : public ExtensionsCallback {
public:
/**
* Does not take ownership of 'nss' or 'txn'.
*
* 'nss' must outlive this object. 'txn' must outlive this object also; in addition, 'txn' must
* outlive any MatchExpression objects generated by these callbacks (as the generated objects
* are allowed to keep a reference to 'txn').
*/
- ExtensionsCallbackReal(OperationContext* txn, const NamespaceString* nss);
+ ExtensionsCallbackReal(OperationContext* opCtx, const NamespaceString* nss);
/**
* Returns a TextMatchExpression, or an error Status if parsing fails.
@@ -61,7 +62,7 @@ public:
StatusWithMatchExpression parseWhere(BSONElement where) const final;
private:
- OperationContext* const _txn;
+ OperationContext* const _opCtx;
const NamespaceString* const _nss;
};
@@ -42,13 +42,14 @@ class OperationContext;
public:
/**
- * Does not take ownership of 'nss' or 'txn'.
+ * Does not take ownership of 'nss' or 'opCtx'.
*
@@ -42,13 +42,14 @@ class OperationContext;
*
- * 'nss' must outlive this object. 'txn' must outlive this object also; in addition, 'txn' must
+ * 'nss' must outlive this object. 'opCtx' must outlive this object also; in addition, 'opCtx'
+ * must
* outlive any MatchExpression objects generated by these callbacks (as the generated objects
@@ -42,13 +42,14 @@ class OperationContext;
* outlive any MatchExpression objects generated by these callbacks (as the generated objects
- * are allowed to keep a reference to 'txn').
+ * are allowed to keep a reference to 'opCtx').
*/